@@ -1,7 +1,7 @@
 ##################################################################################################################
 plot.HCPC <- function(x, axes=c(1,2), choice="3D.map", rect=TRUE, draw.tree=TRUE,
   ind.names=TRUE, t.level="all", title=NULL,
-  new.plot=TRUE, max.plot=15,tree.barplot=TRUE,
+  new.plot=FALSE, max.plot=15,tree.barplot=TRUE,
   centers.plot=FALSE,...){
   
 ######## sub-function #############################################################################################
